<?php
namespace Ems\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\{Message, Error};
use Zeedhi\Framework\DataSource\DataSet;

use Ems\Services\IntervaloService;

class IntervaloController {

    /** @var IntervaloService */
    protected $intervaloService;

    public function __construct(
        IntervaloService $intervaloService
    ) {
      $this->intervaloService  = $intervaloService;
    }

    public function insertIntervalo(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $nrVinculo     = (int)    $row['NRVINCULOM'];
            $date          = (string) $row['DATE'];
            $horarioInicio = (string) $row['HORARIO_INICIO'];
            $horarioFim    =          $row['HORARIO_FIM'] ?? null;
            $before        = (bool)   $row['BEFORE'];
            $ocorrenciaRow = (array)  $row['ocorrencia'];

            $status = $this->intervaloService->insertIntervalo(
                $nrVinculo, $date, $horarioInicio,
                $before, $ocorrenciaRow, $horarioFim
            );

            $response->addDataSet(new DataSet('insertIntervalo', $status));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deleteIntervalo(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $nrVinculo  = (int)    $row['NRVINCULOM'];
            $date       = (string) $row['DATE'];
            $hrInicio   = (string) $row['DTHRINICIO'];
            $hrFim      = (string) $row['DTHRFIM'];
            $before     = (bool)   $row['before'];

            $status = $this->intervaloService->deleteIntervalo(
                $nrVinculo, $date, $hrInicio,
                $hrFim, $before
            );

            $response->addDataSet(new DataSet('deleteIntervalo', $status));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
}